#!/bin/bash

shopt -s expand_aliases
set -e # exit script after failing commands

# This script must be run in a directory named as a date in the format "YYMM" ! #######

mapdate="1502"
basedir='/data/gps'
mkgmap_ver='3447'
mystylefile="${basedir}/mkgmap-style-toponew-nobuilding-1411/"
mystylebldg="${basedir}/mkgmap-style-toponew-building-1411/"
mybounds="${basedir}/bounds_20141027"
mysea="${basedir}/sea_20150206.zip"
alias myjava='/usr/java/jre1.7.0_45/bin/java -enableassertions -Xmx8192M'
alias mysplitter="myjava -jar ${basedir}/splitter-r421/splitter.jar"
alias mymkgmap="myjava -jar /data/gps/mkgmap-r${mkgmap_ver}/mkgmap.jar"
alias mygmt="${basedir}/wgmaptool08186/gmt -LicenseAcknowledge"
typver='89'
typ_germany="M${typver}_1331.TYP"
typ_1332="M${typver}_1332.TYP"
typ_1333="M${typver}_1333.TYP"
typ_1334="M${typver}_1334.TYP"
typ_srtm10="M2_2512.TYP"
typ_srtm20="M2_2513.TYP"
typ_srtm100="M2_2514.TYP"
geonamesfile="${basedir}/geonames/cities5000.txt"

source='planet-150204.osm.pbf'
source_date=`echo $source | sed -e "s/\(.*planet-\)\(..\)\(..\)\(..\).osm.pbf/\4.\3.\2/"`

function 01_links() {
echo "---------- Links start ..."

ln -fs ${basedir}/1110/2?000???.img .
ln -fs ${basedir}/typ/${typ_germany} .
ln -fs ${basedir}/typ/${typ_srtm10} .
ln -fs ${basedir}/typ/${typ_srtm20} .
ln -fs ${basedir}/typ/${typ_srtm100} .
ln -fs ${basedir}/typ/${typ_1332} .
ln -fs ${basedir}/typ/${typ_1333} .
ln -fs ${basedir}/typ/${typ_1334} .
ln -fs ${basedir}/1311/germany/OSM_Germany_license.txt .
ln -fs ${basedir}/1311/germany/OSM_SRTM_Germany_license.txt .
ln -fs ${basedir}/1311/alps/OSM_SRTM_Alps_license.txt .
ln -fs ${basedir}/GmapTool061/gmt/gmt.exe .
ln -fs ${basedir}/1311/germany/OSM_Germany_license.txt OSM_Alps_license.txt
ln -fs ${basedir}/1311/germany/OSM_Germany_license.txt OSM_SRTM_Alps_license.txt

echo "---------- Links end"
}
function 02_split() {
# Grobsplit:

echo "---------- Split start ..."

cat > areas_newsplit.list <<EOF
echo '# Germany north:
00000001: 2238464,268288 to 2574336,704512
#       : 48.032616,5.756883,55.239706,15.117310
# Germany south / Alps north:
00000002: 2199552,268288 to 2238464,704512
#       : 47.197648,5.756883,48.032616,15.117310
# Alps west:
00000003: 2097152,186368 to 2238464,268288
#       : 45.000365,3.999056,48.032616,5.756883
# Alps south:
00000004: 1957888,186368 to 2097152,468992
#       : 42.012059,3.999056,45.000365,10.063558
# Alps center:
00000005: 2097152,268288 to 2199552,704512
#       : 45.000365,5.756883,47.197648,15.117310
# Alps east:
00000006: 2097152,704512 to 2238464,837632
#       : 45.000365,15.117310,48.032616,17.973779
EOF

mysplitter --mapid=10000001 --output=pbf --split-file=areas_newsplit.list ${basedir}/${source}

mysplitter --output=pbf --geonames-file=${geonamesfile} --max-nodes=2500000 --mapid=10000001 00000001.osm.pbf
mv template.args template1.args
mv areas.list areas1.list
mysplitter --output=pbf --geonames-file=${geonamesfile} --max-nodes=2500000 --mapid=10000200 00000002.osm.pbf
mv template.args template2.args
mv areas.list areas2.list
mysplitter --output=pbf --geonames-file=${geonamesfile} --max-nodes=2500000 --mapid=10000300 00000003.osm.pbf
mv template.args template3.args
mv areas.list areas3.list
mysplitter --output=pbf --geonames-file=${geonamesfile} --max-nodes=2500000 --mapid=10000400 00000004.osm.pbf
mv template.args template4.args
mv areas.list areas4.list
mysplitter --output=pbf --geonames-file=${geonamesfile} --max-nodes=2500000 --mapid=10000500 00000005.osm.pbf
mv template.args template5.args
mv areas.list areas5.list
mysplitter --output=pbf --geonames-file=${geonamesfile} --max-nodes=2500000 --mapid=10000600 00000006.osm.pbf
mv template.args template6.args
mv areas.list areas6.list

echo "---------- Split end"
}
function 03_mkgmap_nobuilding() {
echo "---------- Mkgmap start"

cat > template_nofiles.args <<EOF
description=OSM_Germany_Alps
country-name=Germany
country-abbr=DE
region-name=Germany
region-abbr=DE
#overview-mapname=OSM_Germany_Alps
#overview-mapnumber=10000000
remove-ovm-work-files=no
######################################################################
latin1
############# --code-page=65001 --index --route ### Unicode ab r3294 #
reduce-point-density=4
merge-lines=yes
family-id=1331
product-id=1
series-name=OSM_SRTM_Germany_Alps
family-name=OSM_Germany
area-name=Germany
index
style-file=$mystylefile
#style=$mystyle
tdbfile=no
route=yes

############ Testen ?
############ --process-destination and --process-exits. #########
 
road-name-pois=0x640a
add-pois-to-areas
make-opposite-cycleways=yes
remove-short-arcs
adjust-turn-headings
housenumbers
link-pois-to-ways
bounds=$mybounds
location-autofill=bounds,is_in,nearest
precomp-sea=$mysea
generate-sea
EOF

for n in 1 2 3 4 5 6
do
  echo "----------------- part $n start"
  mymkgmap -c template_nofiles.args --overview-mapname=OSM_Germany_Alps_${n} --overview-mapnumber=100${n}0000 -c template${n}.args
  echo "----------------- part $n end"
done

echo "---------- Mkgmap end"
}
function 04_mkgmap_building() {
echo "---------- Mkgmap building start"

cat > template_nofiles_building.args <<EOF
description=OSM_Germany_Alps
country-name=Germany
country-abbr=DE
region-name=Germany
region-abbr=DE
#overview-mapname=OSM_Germany_Alps
#overview-mapnumber=10000000
latin1
reduce-point-density=4
merge-lines=yes
family-id=1331
product-id=1
series-name=OSM_SRTM_Germany_Alps
family-name=OSM_Germany
area-name=Germany
index
style-file=$mystylebldg
transparent=yes
tdbfile=no
route=no
road-name-pois=0x640a
add-pois-to-areas
make-opposite-cycleways=yes
remove-short-arcs
adjust-turn-headings
link-pois-to-ways
draw-priority=30
bounds=$mybounds
location-autofill=bounds,is_in,nearest
precomp-sea=$mysea
EOF
 
for n in 1 2 3 4 5 6
do
  echo "----------------- part $n start"
  sed -e "s/^description: /description: Bldg_/" -e "s/mapname: 1/mapname: 4/" template${n}.args > template${n}_building.args
  mymkgmap -c template_nofiles_building.args -c template${n}_building.args
#  rm -f template${n}.args template${n}_building.arg
  echo "----------------- part $n end"
done

if (( `find . -maxdepth 1 -iname "?0000???.img" -empty | wc -l` ))
then 
  echo "Empty files !!!"
  exit 
fi

rm -f OSM_Germany_Alps.img OSM_Germany_Alps.tdb OSM_Germany_Alps_mdr.img OSM_Germany_Alps.mdx

echo "---------- Mkgmap building end"
}
function 05_copy_tiles() {
echo "---------- Copy start"

# Copy the southern germany / northern alps tile to a new number and change the map id accordingly;
# Otherwise you cannot use the germany and the alps map at the same time on one garmin device
for file in 100002??.img 400002??.img
do
  newfile=`echo $file | sed -e 's/^\(.\)0000/\10001/'`
  cp $file $newfile  
  mygmt -w -e +1000 $newfile
done
for file in ovm_100002??.img
do
  newfile=`echo $file | sed -e 's/^\ovm_10000/\ovm_10001/'`
  cp $file $newfile  
  mygmt -w -e +1000 $newfile
done

echo "---------- Copy end"
}
function 06_reb_all_in_one() {
echo "---------- Rebuild all-in-one start"

# All in one:
cat > template_reb_germany.args <<EOF
description=OSM_SRTM_Germany
country-name=Germany
country-abbr=DE
region-name=Germany
region-abbr=DE
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
#overview-mapname=OV_Germany
overview-mapname=10002000
overview-mapnumber=10002000
latin1
series-name=OSM_SRTM_Germany
area-name=Germany
#bounds=/data/gps/boundary/bounds
#location-autofill=bounds,is_in,nearest
gmapsupp

family-id=1331
product-id=1
family-name=OSM_Germany
index
tdbfile=no
EOF

for file in ovm_10000[0-2]??.img 10000[0-2]??.img
do
  echo "input-file: $file" >> template_reb_germany.args
done

cat >> template_reb_germany.args <<EOF
input-file: $typ_germany
family-id=2512
product-id=1
family-name=SRTM10_Germany
input-file: 21000001.img
input-file: 21000002.img
input-file: 21000003.img
input-file: 21000004.img
input-file: 21000005.img
input-file: 21000006.img
input-file: 21000007.img
input-file: 21000008.img
input-file: 21000009.img
input-file: 21000010.img
input-file: 21000011.img
input-file: 21000012.img
input-file: 21000013.img
input-file: 21000014.img
input-file: 21000015.img
input-file: 21000016.img
input-file: 21000017.img
input-file: ${typ_srtm10}
family-id=2513
product-id=1
family-name=SRTM20_Germany
input-file: 22000001.img
input-file: 22000002.img
input-file: 22000003.img
input-file: 22000004.img
input-file: 22000005.img
input-file: 22000006.img
input-file: 22000007.img
input-file: 22000008.img
input-file: 22000009.img
input-file: 22000010.img
input-file: 22000011.img
input-file: 22000012.img
input-file: 22000013.img
input-file: 22000014.img
input-file: 22000015.img
input-file: 22000016.img
input-file: 22000017.img
input-file: ${typ_srtm20}
family-id=2514
product-id=1
family-name=SRTM100_Germany
input-file: 23000001.img
input-file: 23000002.img
input-file: 23000003.img
input-file: 23000004.img
input-file: 23000005.img
input-file: ${typ_srtm100}
family-id=1333
product-id=1
family-name=Bldg_Germany
input-file: ${typ_1333}
EOF

for file in 40000[0-2]??.img
do
  echo "input-file: $file" >> template_reb_germany.args
done

mymkgmap -c template_reb_germany.args

mv gmapsupp.img germany_osm_srtm_noov.img

egrep -v 'input-file: ovm_[0-9]{8}.img' template_reb_germany.args > template_reb_germany_ov.args
#sed -i -e "s/input-file: 10000001.img/input-file: OV_Germany.img\ninput-file: 10000001.img/" template_reb_germany_ov.args
#sed -i -e "s/input-file: 10000001.img/input-file: 10002000.img\ninput-file: 10000001.img/" template_reb_germany_ov.args
sed -i -e "s/input-file: M${typver}_1331.TYP/input-file: 10002000.img\ninput-file: M${typver}_1331.TYP/" template_reb_germany_ov.args
sed -i -e "s/overview-mapname=10002000/overview-mapname=OV_Germany_tmp/" template_reb_germany_ov.args
sed -i -e "s/overview-mapnumber=10002000/overview-mapnumber=99999999/" template_reb_germany_ov.args

mymkgmap -c template_reb_germany_ov.args

rm -f OV_Germany_tmp
mv gmapsupp.img germany_osm_srtm.img

echo "---------- Rebuild all-in-one end"
}
function 07_check_all_in_one() {
echo "---------- Check all-in-one start"

# Check if all files are in the gmapsupp.img, sometimes some are too big!
n_gmt=`mygmt -i germany_osm_srtm.img | egrep "^ 10000[0-2]..\sMPC" | wc -l`
n_files=`ls 10000[0-2]??.img | wc -l`
if [ "$n_gmt" -ne "$n_files" ]
then
  echo "Not all OSM files in germany_osm.img !!!"
  exit
fi
n_gmt=`mygmt -i germany_osm_srtm.img | egrep "^ 40000[0-2]..\sMPC" | wc -l`
n_files=`ls 40000[0-2]??.img | wc -l`
if [ "$n_gmt" -ne "$n_files" ]
then
  echo "Not all building files in germany_osm.img !!!"
  exit
fi

echo "---------- Check all-in-one end"
}
function 08_reb_osm() {
echo "---------- Rebuild OSM start"

cat > template_reb_germany_osm.args <<EOF
description=OSM_Germany
country-name=Germany
country-abbr=DE
region-name=Germany
region-abbr=DE
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
overview-mapname=OSM_Germany
overview-mapnumber=99999999
latin1
series-name=OSM_Germany
area-name=Germany
gmapsupp

family-id=1331
product-id=1
family-name=OSM_Germany
index
tdbfile=no
input-file: $typ_germany
EOF

for file in 10000[0-2]??.img 10002000.img
do
  echo "input-file: $file" >> template_reb_germany_osm.args
done

mymkgmap -c template_reb_germany_osm.args
mv gmapsupp.img germany_osm.img

echo "---------- Rebuild OSM end"
}
function 09_reb_srtm10() {
echo "---------- Rebuild SRTM10 start"

cat > template_reb_germany_srtm10.args <<EOF
description=SRTM10_Germany
country-name=Germany
country-abbr=DE
region-name=Germany
region-abbr=DE
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
latin1
series-name=OSM_SRTM_Germany
area-name=Test
gmapsupp
family-id=2512
product-id=1
family-name=SRTM10_Germany
input-file: ${typ_srtm10}
EOF

for file in 2100000?.img 2100001[0-7].img
do
  echo "input-file: $file" >> template_reb_germany_srtm10.args
done

mymkgmap -c template_reb_germany_srtm10.args
mv gmapsupp.img germany_srtm10.img

echo "---------- Rebuild SRTM10 end"
}
function 10_reb_srtm20() {
echo "---------- Rebuild SRTM20 start"

cat > template_reb_germany_srtm20.args <<EOF
description=SRTM20_Germany
country-name=Germany
country-abbr=DE
region-name=Germany
region-abbr=DE
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
latin1
series-name=OSM_SRTM_Germany
area-name=Test
gmapsupp
family-id=2513
product-id=1
family-name=SRTM20_Germany
input-file: $typ_srtm20
EOF

for file in 2200000?.img 2200001[0-7].img
do
  echo "input-file: $file" >> template_reb_germany_srtm20.args
done

mymkgmap -c template_reb_germany_srtm20.args
mv gmapsupp.img germany_srtm20.img

echo "---------- Rebuild SRTM20 end"
}
function 11_reb_srtm100() {
echo "---------- Rebuild SRTM100 start"

cat > template_reb_germany_srtm100.args <<EOF
description=SRTM100_Germany                                                                                                            
country-name=Germany                                                                                                                   
country-abbr=DE
region-name=Germany
region-abbr=DE
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
latin1
series-name=OSM_SRTM_Germany
area-name=Test
gmapsupp
family-id=2514
product-id=1
family-name=SRTM100_Germany
input-file: $typ_srtm100
EOF

for file in 2300000[1-5].img 
do
  echo "input-file: $file" >> template_reb_germany_srtm100.args
done
mymkgmap -c template_reb_germany_srtm100.args
mv gmapsupp.img germany_srtm100.img

## SRTM100 Zip file:
#zip -q "germany_srtm100_${mapdate}.zip" germany_srtm100.img
#rm germany_srtm100.img

echo "---------- Rebuild SRTM100 end"
}
function 12_reb_bldg() {
echo "---------- Rebuild building start"

cat > template_reb_germany_building.args <<EOF
description=Bldg_Germany
country-name=Germany
country-abbr=DE
region-name=Germany
region-abbr=DE
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
latin1
series-name=OSM_SRTM_Germany
area-name=Bldg_Germany
gmapsupp
family-id=1333
product-id=1
family-name=Bldg_Germany
input-file: $typ_1333
EOF

for file in 40000[0-2]??.img 
do
  echo "input-file: $file" >> template_reb_germany_building.args
done

mymkgmap -c template_reb_germany_building.args
mv gmapsupp.img germany_bldg.img

zip -q "germany_bldg_${mapdate}.zip" germany_bldg.img

echo "---------- Rebuild building end"

}
function 13_ms_all_in_one() {
echo "---------- MS all-in-one start"

cat > template_ms_germany.args <<EOF
description=OSM_SRTM_Germany
country-name=Germany
country-abbr=DE
region-name=Germany
region-abbr=DE
overview-mapname=OSM_SRTM_Germany
overview-mapnumber=10002000
latin1
series-name=OSM_SRTM_Germany
area-name=Germany
family-id=1331
product-id=1
family-name=OSM_Germany
index
tdbfile=yes
input-file: $typ_germany
EOF

for file in 10000[0-2]??.img 2100000?.img 2100001[0-7].img 2200000?.img 2200001[0-7].img 2300000[1-5].img 40000[0-2]??.img
do
  echo "input-file: $file" >> template_ms_germany.args
done

mymkgmap -c template_ms_germany.args

echo "---------- MS all-in-one end"
}
function 14_nsis_all_in_one() {
echo "---------- NSIS all-in-one start"

#All in one NSIS installer:
cat > OSM_SRTM_Germany.nsi <<EOF
!define DEFAULT_DIR "C:\Garmin\Maps\OSM_SRTM_Germany"
!define INSTALLER_DESCRIPTION "OSM_SRTM_Germany"
!define INSTALLER_NAME "OSM_SRTM_Germany"
!define MAPNAME "OSM_SRTM_Germany"
!define PRODUCT_ID "1"
!define REG_KEY "OSM_SRTM_Germany"
!define APP_NAME execDos
!define DOS_APP consApp.exe
!define TYP_VER "$typver"
SetCompressor /SOLID lzma
!include "MUI2.nsh"
!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE \${MAPNAME}_license.txt
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES
!insertmacro MUI_PAGE_FINISH
!define MUI_UNPAGE_INSTFILES
!insertmacro MUI_LANGUAGE "English"
Name "\${INSTALLER_DESCRIPTION}"
OutFile "\${INSTALLER_NAME}.exe"
InstallDir "\${DEFAULT_DIR}"
Section "MainSection" SectionMain
  SetOutPath "\$INSTDIR"
  File "gmt.exe"
  File "\${MAPNAME}.img"
  File "\${MAPNAME}.tdb"
  File "\${MAPNAME}.mdx"
  File "\${MAPNAME}_mdr.img"
  WriteRegBin HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "ID" 3305
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "BMAP" "\$INSTDIR\\\${MAPNAME}.img"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "LOC" "\$INSTDIR"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "TDB" "\$INSTDIR\\\${MAPNAME}.tdb"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "TYP" "\$INSTDIR\M\${TYP_VER}_1331.TYP"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "IDX" "\$INSTDIR\\\${MAPNAME}.mdx"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "MDR" "\$INSTDIR\\\${MAPNAME}_mdr.img"
  WriteUninstaller "\$INSTDIR\Uninstall.exe"
  ExecDos::exec '"\$INSTDIR\gmt.exe" -s -o "\$INSTDIR" "\$EXEDIR\gmapsupp.img"'
EOF

echo -n "  AddSize " >> OSM_SRTM_Germany.nsi
# echo `expr \`find . -name germany_osm_srtm.img -printf '%s'\` / 1024` >> OSM_SRTM_Germany.nsi
echo $( expr $(find . -maxdepth 1 -name germany_osm_srtm.img -printf '%s') / 1024) >> OSM_SRTM_Germany.nsi

cat >> OSM_SRTM_Germany.nsi <<EOF
  Delete "\$INSTDIR\gmt.exe"
  Delete "\$INSTDIR\MAKEGMAP.mps"
SectionEnd
Section "Uninstall"
  Delete "\$INSTDIR\\\${MAPNAME}.img"
  Delete "\$INSTDIR\Uninstall.exe"
  Delete "\$INSTDIR\\\${MAPNAME}.tdb"
EOF

for file in 10000[0-2]??.img 10002000.img 2100000?.img 2100001[0-7].img 2200000?.img 2200001[0-7].img 2300000[1-5].img 40000[0-2]??.img
do
  echo "  Delete \"\$INSTDIR\\$file\"" >> OSM_SRTM_Germany.nsi
done

cat >> OSM_SRTM_Germany.nsi <<EOF
  Delete "\$INSTDIR\M\${TYP_VER}_1331.typ"
  Delete "\$INSTDIR\M\${TYP_VER}_1333.typ"
  Delete "\$INSTDIR\0${typ_srtm10}"
  Delete "\$INSTDIR\0${typ_srtm20}"
  Delete "\$INSTDIR\0${typ_srtm100}"
  Delete "\$INSTDIR\MAKEGMAP.MPS"
  Delete "\$INSTDIR\\\${MAPNAME}.mdx"
  Delete "\$INSTDIR\\\${MAPNAME}_mdr.img"
  Delete "\$INSTDIR\1331_mdr.img"
  Delete "\$INSTDIR\1333_mdr.img"
  Delete "\$INSTDIR\2512_mdr.img"
  Delete "\$INSTDIR\2513_mdr.img"
  Delete "\$INSTDIR\2514_mdr.img"
  Delete "\$INSTDIR\gmt.exe"
  RmDir "\$INSTDIR"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "ID"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "BMAP"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "LOC"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "TDB"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "TYP"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "IDX"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "MDR"
  DeleteRegKey /IfEmpty HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}"
  DeleteRegKey /IfEmpty HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}"
SectionEnd
EOF

makensis -V2 OSM_SRTM_Germany.nsi

echo "---------- NSIS all-in-one end"
}
function 15_zip_all_in_one() {
echo "---------- Zip all-in-one start"

rm -f "osm_srtm_germany_${mapdate}.zip"

# All in one Germany Zip file:
ln -s germany_osm_srtm.img gmapsupp.img
zip -q "osm_srtm_germany_${mapdate}.zip" OSM_SRTM_Germany.exe gmapsupp.img OSM_SRTM_Germany.img OSM_SRTM_Germany.tdb
rm gmapsupp.img

echo "---------- Zip all-in-one end"
}
function 16_ms_osm() {
echo "---------- MS OSM start"

# OSM only MS rebuild:
cat > template_ms_germany_osm.args <<EOF
description=OSM_Germany
country-name=Germany
country-abbr=DE
region-name=Germany
region-abbr=DE
overview-mapname=OSM_Germany
overview-mapnumber=10002000
latin1
series-name=OSM_Germany
area-name=Test
family-id=1331
product-id=1
family-name=OSM_Germany
index
tdbfile=yes
input-file: $typ_germany
EOF

for file in 10000[0-2]??.img 
do
  echo "input-file: $file" >> template_ms_germany_osm.args
done

mymkgmap -c template_ms_germany_osm.args

echo "---------- MS OSM end"
}
function 17_nsis_osm() {
echo "---------- NSIS OSM start"

# OSM only NSIS installer

ln -s germany_osm.img gmapsupp.img

cat > OSM_Germany.nsi <<EOF
!define DEFAULT_DIR "C:\Garmin\Maps\OSM_Germany"
!define INSTALLER_DESCRIPTION "OSM_Germany"
!define INSTALLER_NAME "OSM_Germany"
!define MAPNAME "OSM_Germany"
!define PRODUCT_ID "1"
!define REG_KEY "OSM_Germany"
!define APP_NAME execDos
!define DOS_APP consApp.exe
!define TYP_VER "$typver"
SetCompressor /SOLID lzma
!include "MUI2.nsh"
!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE \${MAPNAME}_license.txt
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES
!insertmacro MUI_PAGE_FINISH
!define MUI_UNPAGE_INSTFILES
!insertmacro MUI_LANGUAGE "English"
Name "\${INSTALLER_DESCRIPTION}"
OutFile "\${INSTALLER_NAME}.exe"
InstallDir "\${DEFAULT_DIR}"
Section "MainSection" SectionMain
  SetOutPath "\$INSTDIR"
  File "gmt.exe"
  File "\${MAPNAME}.img"
  File "\${MAPNAME}.tdb"
  File "\${MAPNAME}.mdx"
  File "\${MAPNAME}_mdr.img"
  WriteRegBin HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "ID" 3305
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "BMAP" "\$INSTDIR\\\${MAPNAME}.img"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "LOC" "\$INSTDIR"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "TDB" "\$INSTDIR\\\${MAPNAME}.tdb"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "TYP" "\$INSTDIR\M\${TYP_VER}_1331.TYP"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "IDX" "\$INSTDIR\\\${MAPNAME}.mdx"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "MDR" "\$INSTDIR\\\${MAPNAME}_mdr.img"
  WriteUninstaller "\$INSTDIR\Uninstall.exe"
  ExecDos::exec '"\$INSTDIR\gmt.exe" -s -o "\$INSTDIR" "\$EXEDIR\gmapsupp.img"'
EOF

echo -n "  AddSize " >> OSM_Germany.nsi
echo $( expr $(find . -maxdepth 1 -name germany_osm.img -printf '%s') / 1024) >> OSM_Germany.nsi

cat >> OSM_Germany.nsi <<EOF
  Delete "\$INSTDIR\gmt.exe"
  Delete "\$INSTDIR\MAKEGMAP.mps"
SectionEnd
Section "Uninstall"
  Delete "\$INSTDIR\\\${MAPNAME}.img"
  Delete "\$INSTDIR\Uninstall.exe"
  Delete "\$INSTDIR\\\${MAPNAME}.tdb"
EOF

for file in 10000[0-2]??.img 10002000.img
do
  echo "  Delete \"\$INSTDIR\\$file\"" >> OSM_Germany.nsi
done

cat >> OSM_Germany.nsi <<EOF
  Delete "\$INSTDIR\M\${TYP_VER}_1331.typ"
  Delete "\$INSTDIR\MAKEGMAP.MPS"
  Delete "\$INSTDIR\\\${MAPNAME}.mdx"
  Delete "\$INSTDIR\\\${MAPNAME}_mdr.img"
  Delete "\$INSTDIR\1331_mdr.img"
  Delete "\$INSTDIR\gmt.exe"
  RmDir "\$INSTDIR"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "ID"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "BMAP"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "LOC"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "TDB"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "TYP"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "IDX"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "MDR"
  DeleteRegKey /IfEmpty HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}"
  DeleteRegKey /IfEmpty HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}"
SectionEnd
EOF

#cp /data/gps/1311/germany/OSM_Germany_license.txt .
makensis -V2 OSM_Germany.nsi

rm -f gmapsupp.img

echo "---------- NSIS OSM end"
}
function 18_zip_osm() {
echo "---------- Zip OSM start"

rm -f "germany_osm_${mapdate}.zip"

# OSM only Germany Zip file:
ln -s germany_osm.img gmapsupp.img
zip -q germany_osm_${mapdate}.zip OSM_Germany.exe gmapsupp.img OSM_Germany.img OSM_Germany.tdb
#zip -q germany_osm_${mapdate}.zip OSM_Germany.exe germany_osm.img OSM_Germany.img OSM_Germany.tdb
rm -f gmapsupp.img

echo "---------- Zip OSM end"

}
function 19_zip_srtm() {
echo "---------- Zip SRTM start"

rm -f "germany_srtm10_${mapdate}.zip" "germany_srtm20_${mapdate}.zip" "germany_srtm100_${mapdate}.zip"

# SRTM10 Zip file:
zip -q "germany_srtm10_${mapdate}.zip" germany_srtm10.img

# SRTM20 Zip file:
zip -q "germany_srtm20_${mapdate}.zip" germany_srtm20.img

# SRTM100 Zip file:
zip -q "germany_srtm100_${mapdate}.zip" germany_srtm100.img

echo "---------- Zip SRTM end"
}
function 20_md5sum() {
echo "---------- md5sum start"

md5sum osm_srtm_germany_${mapdate}.zip germany_osm_${mapdate}.zip germany_srtm10_${mapdate}.zip germany_srtm20_${mapdate}.zip germany_srtm100_${mapdate}.zip germany_bldg_${mapdate}.zip > md5sums_germany.txt 

echo "---------- md5sum end"
}
function 24_reb_all_in_one_alps() {
echo "---------- Rebuild all-in-one alps start"

# All in one:
cat > template_reb_alps.args <<EOF
description=OSM_SRTM_Alps
country-name=Alps
country-abbr=ALP
region-name=Alps
region-abbr=ALP
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
overview-mapname=OV_Alps
overview-mapnumber=10002001
latin1
series-name=OSM_SRTM_Alps
area-name=Alps
gmapsupp

family-id=1332
product-id=1
family-name=OSM_Alps
index
tdbfile=no
EOF

for file in ovm_10000[2-6]??.img 10000[2-6]??.img
do
  echo "input-file: $file" >> template_reb_alps.args
done

cat >> template_reb_alps.args <<EOF
input-file: ${typ_1332}
family-id=2512
product-id=1
family-name=SRTM10_Alps
input-file: 21000018.img
input-file: 21000019.img
input-file: 21000020.img
input-file: 21000021.img
input-file: 21000022.img
input-file: 21000023.img
input-file: 21000024.img
input-file: 21000025.img
input-file: 21000026.img
input-file: 21000027.img
input-file: 21000028.img
input-file: 21000029.img
input-file: 21000030.img
input-file: 21000031.img
input-file: 21000032.img
input-file: 21000033.img
input-file: 21000034.img
input-file: 21000035.img
input-file: 21000036.img
input-file: 21000037.img
input-file: 21000038.img
input-file: 21000039.img
input-file: 21000040.img
input-file: 21000041.img
input-file: 21000042.img
input-file: 21000051.img
input-file: 21000052.img
input-file: 21000053.img
input-file: 21000054.img
input-file: 21000055.img
input-file: ${typ_srtm10}
family-id=2513
product-id=1
family-name=SRTM20_Alps
input-file: 22000018.img
input-file: 22000019.img
input-file: 22000020.img
input-file: 22000021.img
input-file: 22000022.img
input-file: 22000023.img
input-file: 22000024.img
input-file: 22000025.img
input-file: 22000026.img
input-file: 22000027.img
input-file: 22000028.img
input-file: 22000029.img
input-file: 22000030.img
input-file: 22000031.img
input-file: 22000032.img
input-file: 22000033.img
input-file: 22000034.img
input-file: 22000035.img
input-file: 22000036.img
input-file: 22000037.img
input-file: 22000038.img
input-file: 22000039.img
input-file: 22000040.img
input-file: 22000041.img
input-file: 22000042.img
input-file: 22000051.img
input-file: 22000052.img
input-file: 22000053.img
input-file: 22000054.img
input-file: 22000055.img
input-file: ${typ_srtm20}
family-id=2514
product-id=1
family-name=SRTM100_Alps
input-file: 23000018.img
input-file: 23000019.img
input-file: 23000020.img
input-file: 23000021.img
input-file: 23000022.img
input-file: 23000023.img
input-file: 23000024.img
input-file: 23000025.img
input-file: 23000026.img
input-file: 23000027.img
input-file: 23000028.img
input-file: 23000029.img
input-file: 23000030.img
input-file: 23000031.img
input-file: 23000032.img
input-file: 23000033.img
input-file: 23000034.img
input-file: 23000035.img
input-file: 23000036.img
input-file: 23000037.img
input-file: 23000038.img
input-file: 23000039.img
input-file: 23000040.img
input-file: 23000041.img
input-file: 23000042.img
input-file: 23000051.img
input-file: 23000052.img
input-file: 23000053.img
input-file: 23000054.img
input-file: 23000055.img
input-file: ${typ_srtm100}
family-id=1334
product-id=1
family-name=Bldg_Alps
input-file: ${typ_1334}
EOF

for file in 40000[2-6]??.img
do
  echo "input-file: $file" >> template_reb_alps.args
done

mymkgmap -c template_reb_alps.args

mv gmapsupp.img alps_osm_srtm_noov.img

egrep -v 'input-file: ovm_[0-9]{8}.img' template_reb_alps.args > template_reb_alps_ov.args
sed -i -e "s/input-file: M${typver}_1332.TYP/\ninput-file: 10002001.img\ninput-file: M${typver}_1332.TYP/" template_reb_alps_ov.args

mymkgmap -c template_reb_alps_ov.args


mv gmapsupp.img alps_osm_srtm.img

echo "---------- Rebuild all-in-one alps end"

}
function 25_check_all_in_one_alps() {
echo "---------- Check all-in-one alps start"

# Check if all files are in the gmapsupp.img, sometimes some are too big!
n_gmt=`mygmt -i alps_osm_srtm.img | egrep "^ 10000[2-6]..\sMPC" | wc -l`
n_files=`ls 10000[2-6]??.img | wc -l`
if [ "$n_gmt" -ne "$n_files" ]
then
  echo "Not all OSM files in alps_osm_srtm.img !!!"
  exit
fi
n_gmt=`mygmt -i alps_osm_srtm.img | egrep "^ 40000[2-6]..\sMPC" | wc -l`
n_files=`ls 40000[2-6]??.img | wc -l`
if [ "$n_gmt" -ne "$n_files" ]
then
  echo "Not all building files in alps_osm_srtm.img !!!"
  exit
fi

echo "---------- Check all-in-one alps end"
}
function 26_reb_osm_alps() {
echo "---------- Rebuild osm alps start"

# All in one:
cat > template_reb_alps_osm.args <<EOF
description=OSM_Alps
country-name=Alps
country-abbr=ALP
region-name=Alps
region-abbr=ALP
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
overview-mapname=OSM_Alps
overview-mapnumber=99999999
latin1
series-name=OSM_Alps
area-name=Alps
gmapsupp

family-id=1332
product-id=1
family-name=OSM_Alps
index
tdbfile=no
input-file: ${typ_1332}
EOF

for file in 10000[2-6]??.img 10002001.img
do
  echo "input-file: $file" >> template_reb_alps_osm.args
done

mymkgmap -c template_reb_alps_osm.args
mv gmapsupp.img alps_osm.img

echo "---------- Rebuild osm alps end"

}
function 27_reb_srtm10_alps() {
echo "---------- Rebuild SRTM10 alps start"

# SRTM10:
cat > template_reb_alps_srtm10.args <<EOF
description=SRTM10_Alps
country-name=Alps
country-abbr=ALP
region-name=Alps
region-abbr=ALP
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
latin1
series-name=OSM_SRTM_Alps
area-name=Test
gmapsupp
family-id=2512
product-id=1
family-name=SRTM10_Alps
input-file: ${typ_srtm10}
EOF

for file in 2100001[8-9].img 210000[2-3]?.img 2100004[0-2].img 2100005[1-5].img
do
  echo "input-file: $file" >> template_reb_alps_srtm10.args
done

mymkgmap -c template_reb_alps_srtm10.args
mv gmapsupp.img alps_srtm10.img
rm -f template_reb_alps_srtm10.args

echo "---------- Rebuild SRTM10 alps end"
}
function 28_reb_srtm20_alps() {
echo "---------- Rebuild SRTM20 alps start"

# SRTM10:
cat > template_reb_alps_srtm20.args <<EOF
description=SRTM20_Alps
country-name=Alps
country-abbr=ALP
region-name=Alps
region-abbr=ALP
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
latin1
series-name=OSM_SRTM_Alps
area-name=Test
gmapsupp
family-id=2513
product-id=1
family-name=SRTM20_Alps
input-file: M2_2513.TYP
EOF

for file in 2200001[8-9].img 220000[2-3]?.img 2200004[0-2].img 2200005[1-5].img
do
  echo "input-file: $file" >> template_reb_alps_srtm20.args
done

mymkgmap -c template_reb_alps_srtm20.args
mv gmapsupp.img alps_srtm20.img
rm -f template_reb_alps_srtm20.args

echo "---------- Rebuild SRTM20 alps end"
}
function 29_reb_srtm100_alps() {
echo "---------- Rebuild SRTM100 alps start"

# SRTM100:
cat > template_reb_alps_srtm100.args <<EOF
description=SRTM100_Alps
country-name=Alps
country-abbr=ALP
region-name=Alps
region-abbr=ALP
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
latin1
series-name=OSM_SRTM_Alps
area-name=Test
gmapsupp
family-id=2514
product-id=1
family-name=SRTM100_Alps
input-file: M2_2514.TYP
EOF

for file in 2300001[8-9].img 230000[2-3]?.img 2300004[0-2].img 2300005[1-5].img
do
  echo "input-file: $file" >> template_reb_alps_srtm100.args
done

mymkgmap -c template_reb_alps_srtm100.args
mv gmapsupp.img alps_srtm100.img
rm -f template_reb_alps_srtm100.args

echo "---------- Rebuild SRTM100 alps end"
}
function 30_reb_bldg_alps() {
echo "---------- Rebuild building alps start"

# Building:
cat > template_reb_alps_bldg.args <<EOF
description=Bldg_Alps
country-name=Alps
country-abbr=ALP
region-name=Alps
region-abbr=ALP
name-tag-list="name:mkgmap,name:de,int_name,name:en,name"
#overview-mapname=Bldg_Alps
#overview-mapnumber=10000000
latin1
series-name=Bldg_Alps
area-name=Bldg_Alps
gmapsupp
family-id=1333
product-id=1
family-name=Bldg_Alps
input-file: $typ_1333
EOF

for file in 40000[2-6]??.img 
do
  echo "input-file: $file" >> template_reb_alps_bldg.args
done

mymkgmap -c template_reb_alps_bldg.args
mv gmapsupp.img alps_bldg.img
rm -f template_reb_alps_bldg.args

zip -q "alps_bldg_${mapdate}.zip" alps_bldg.img

echo "---------- Rebuild building alps end"

}
function 31_ms_all_in_one_alps() {
echo "---------- MS all-in-one alps start"

#All in one MS rebuild:
cat > template_ms_alps.args <<EOF
description=OSM_SRTM_Alps
country-name=Alps
country-abbr=ALP
region-name=Alps
region-abbr=ALP
overview-mapname=OSM_SRTM_Alps
overview-mapnumber=10002001
latin1
series-name=OSM_SRTM_Alps
area-name=Alps
family-id=1332
product-id=1
family-name=OSM_Alps
index
tdbfile=yes
input-file: $typ_1332
EOF

for file in 10000[2-6]??.img 2100001[8-9].img 210000[2-3]?.img 2100004[0-2].img 2100005[1-5].img 2200001[8-9].img 220000[2-3]?.img 2200004[0-2].img 2200005[1-5].img 2300001[8-9].img 230000[2-3]?.img 2300004[0-2].img 2300005[1-5].img 40000[2-6]??.img
do
  echo "input-file: $file" >> template_ms_alps.args
done

mymkgmap -c template_ms_alps.args
rm -f template_ms_alps.args

echo "---------- MS all-in-one alps end"
}
function 32_nsis_all_in_one_alps() {
echo "---------- NSIS all-in-one alps start"

#All in one NSIS installer:
cat > OSM_SRTM_Alps.nsi <<EOF
!define DEFAULT_DIR "C:\Garmin\Maps\OSM_SRTM_Alps"
!define INSTALLER_DESCRIPTION "OSM_SRTM_Alps"
!define INSTALLER_NAME "OSM_SRTM_Alps"
!define MAPNAME "OSM_SRTM_Alps"
!define PRODUCT_ID "1"
!define REG_KEY "OSM_SRTM_Alps"
!define APP_NAME execDos
!define DOS_APP consApp.exe
!define TYP_VER "$typver"
SetCompressor /SOLID lzma
!include "MUI2.nsh"
!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE \${MAPNAME}_license.txt
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES
!insertmacro MUI_PAGE_FINISH
!define MUI_UNPAGE_INSTFILES
!insertmacro MUI_LANGUAGE "English"
Name "\${INSTALLER_DESCRIPTION}"
OutFile "\${INSTALLER_NAME}.exe"
InstallDir "\${DEFAULT_DIR}"
Section "MainSection" SectionMain
  SetOutPath "\$INSTDIR"
  File "gmt.exe"
  File "\${MAPNAME}.img"
  File "\${MAPNAME}.tdb"
  File "\${MAPNAME}.mdx"
  File "\${MAPNAME}_mdr.img"
  WriteRegBin HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "ID" 3405
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "BMAP" "\$INSTDIR\\\${MAPNAME}.img"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "LOC" "\$INSTDIR"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "TDB" "\$INSTDIR\\\${MAPNAME}.tdb"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "TYP" "\$INSTDIR\M\${TYP_VER}_1332.TYP"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "IDX" "\$INSTDIR\\\${MAPNAME}.mdx"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "MDR" "\$INSTDIR\\\${MAPNAME}_mdr.img"
  WriteUninstaller "\$INSTDIR\Uninstall.exe"
  ExecDos::exec '"\$INSTDIR\gmt.exe" -s -o "\$INSTDIR" "\$EXEDIR\gmapsupp.img"'
EOF

echo -n "  AddSize " >> OSM_SRTM_Alps.nsi
echo $( expr $(find . -maxdepth 1 -name alps_osm_srtm.img -printf '%s') / 1024) >> OSM_SRTM_Alps.nsi

cat >> OSM_SRTM_Alps.nsi <<EOF
  Delete "\$INSTDIR\gmt.exe"
  Delete "\$INSTDIR\MAKEGMAP.mps"
SectionEnd
Section "Uninstall"
  Delete "\$INSTDIR\\\${MAPNAME}.img"
  Delete "\$INSTDIR\Uninstall.exe"
  Delete "\$INSTDIR\\\${MAPNAME}.tdb"
EOF

for file in 10000[2-6]??.img 10002001.img 2100001[8-9].img 210000[2-3]?.img 2100004[0-2].img 2100005[1-5].img 2200001[8-9].img 220000[2-3]?.img 2200004[0-2].img 2200005[1-5].img 2300001[8-9].img 230000[2-3]?.img 2300004[0-2].img 2300005[1-5].img 40000[2-6]??.img
do
  echo "  Delete \"\$INSTDIR\\$file\"" >> OSM_SRTM_Alps.nsi
done

cat >> OSM_SRTM_Alps.nsi <<EOF
  Delete "\$INSTDIR\M\${TYP_VER}_1332.typ"
  Delete "\$INSTDIR\M\${TYP_VER}_1334.typ"
  Delete "\$INSTDIR\0${typ_srtm10}"
  Delete "\$INSTDIR\0${typ_srtm20}"
  Delete "\$INSTDIR\0${typ_srtm100}"
  Delete "\$INSTDIR\MAKEGMAP.MPS"
  Delete "\$INSTDIR\\\${MAPNAME}.mdx"
  Delete "\$INSTDIR\\\${MAPNAME}_mdr.img"
  Delete "\$INSTDIR\1332_mdr.img"
  Delete "\$INSTDIR\1334_mdr.img"
  Delete "\$INSTDIR\2512_mdr.img"
  Delete "\$INSTDIR\2513_mdr.img"
  Delete "\$INSTDIR\2514_mdr.img"
  Delete "\$INSTDIR\gmt.exe"
  RmDir "\$INSTDIR"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "ID"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "BMAP"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "LOC"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "TDB"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "TYP"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "IDX"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "MDR"
  DeleteRegKey /IfEmpty HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}"
  DeleteRegKey /IfEmpty HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}"
SectionEnd
EOF

makensis -V2 OSM_SRTM_Alps.nsi

echo "---------- NSIS all-in-one alps end"
}
function 33_zip_all_in_one_alps() {
echo "---------- Zip all-in-one alps start"

rm -f "osm_srtm_alps_${mapdate}.zip"

# All in one Alps Zip file:
ln -s alps_osm_srtm.img gmapsupp.img
zip -q "osm_srtm_alps_${mapdate}.zip" OSM_SRTM_Alps.exe gmapsupp.img OSM_SRTM_Alps.img OSM_SRTM_Alps.tdb
rm gmapsupp.img

echo "---------- Zip all-in-one alps end"
}
function 34_ms_osm_alps() {
echo "---------- MS OSM alps start"

# OSM only MS rebuild:
cat > template_ms_alps_osm.args <<EOF
description=OSM_Alps
country-name=Alps
country-abbr=ALP
region-name=Alps
region-abbr=ALP
overview-mapname=OSM_Alps
overview-mapnumber=10002001
latin1
series-name=OSM_Alps
area-name=Test
family-id=1332
product-id=1
family-name=OSM_Alps
index
tdbfile=yes
input-file: ${typ_1332}
EOF

for file in 10000[2-6]??.img 
do
  echo "input-file: $file" >> template_ms_alps_osm.args
done

mymkgmap -c template_ms_alps_osm.args

echo "---------- MS OSM alps end"
}
function 35_nsis_osm_alps() {
echo "---------- NSIS OSM Alps start"

# OSM only NSIS installer:
cat > OSM_Alps.nsi <<EOF
!define DEFAULT_DIR "C:\Garmin\Maps\OSM_Alps"
!define INSTALLER_DESCRIPTION "OSM_Alps"
!define INSTALLER_NAME "OSM_Alps"
!define MAPNAME "OSM_Alps"
!define PRODUCT_ID "1"
!define REG_KEY "OSM_Alps"
!define APP_NAME execDos
!define DOS_APP consApp.exe
!define TYP_VER "$typver"
SetCompressor /SOLID lzma
!include "MUI2.nsh"
!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE \${MAPNAME}_license.txt
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES
!insertmacro MUI_PAGE_FINISH
!define MUI_UNPAGE_INSTFILES
!insertmacro MUI_LANGUAGE "English"
Name "\${INSTALLER_DESCRIPTION}"
OutFile "\${INSTALLER_NAME}.exe"
InstallDir "\${DEFAULT_DIR}"
Section "MainSection" SectionMain
  SetOutPath "\$INSTDIR"
  File "gmt.exe"
  File "\${MAPNAME}.img"
  File "\${MAPNAME}.tdb"
  File "\${MAPNAME}.mdx"
  File "\${MAPNAME}_mdr.img"
  WriteRegBin HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "ID" 3405
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "BMAP" "\$INSTDIR\\\${MAPNAME}.img"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "LOC" "\$INSTDIR"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "TDB" "\$INSTDIR\\\${MAPNAME}.tdb"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "TYP" "\$INSTDIR\M\${TYP_VER}_1332.TYP"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "IDX" "\$INSTDIR\\\${MAPNAME}.mdx"
  WriteRegStr HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "MDR" "\$INSTDIR\\\${MAPNAME}_mdr.img"
  WriteUninstaller "\$INSTDIR\Uninstall.exe"
  ExecDos::exec '"\$INSTDIR\gmt.exe" -s -o "\$INSTDIR" "\$EXEDIR\gmapsupp.img"'
EOF

echo -n "  AddSize " >> OSM_Alps.nsi
echo $( expr $(find . -maxdepth 1 -name alps_osm.img -printf '%s') / 1024) >> OSM_Alps.nsi

cat >> OSM_Alps.nsi <<EOF
  Delete "\$INSTDIR\gmt.exe"
  Delete "\$INSTDIR\MAKEGMAP.mps"
SectionEnd
Section "Uninstall"
  Delete "\$INSTDIR\\\${MAPNAME}.img"
  Delete "\$INSTDIR\Uninstall.exe"
  Delete "\$INSTDIR\\\${MAPNAME}.tdb"
EOF

for file in 10000[2-6]??.img 10002001.img
do
  echo "  Delete \"\$INSTDIR\\$file\"" >> OSM_Alps.nsi
done

cat >> OSM_Alps.nsi <<EOF
  Delete "\$INSTDIR\M\${TYP_VER}_1332.typ"
  Delete "\$INSTDIR\MAKEGMAP.MPS"
  Delete "\$INSTDIR\\\${MAPNAME}.mdx"
  Delete "\$INSTDIR\\\${MAPNAME}_mdr.img"
  Delete "\$INSTDIR\1332_mdr.img"
  Delete "\$INSTDIR\gmt.exe"
  RmDir "\$INSTDIR"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "ID"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "BMAP"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "LOC"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}" "TDB"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "TYP"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "IDX"
  DeleteRegValue HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}" "MDR"
  DeleteRegKey /IfEmpty HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}\\\${PRODUCT_ID}"
  DeleteRegKey /IfEmpty HKLM "SOFTWARE\Garmin\MapSource\Families\\\${REG_KEY}"
SectionEnd
EOF

makensis -V2 OSM_Alps.nsi

echo "---------- NSIS OSM Alps end"
}
function 36_zip_osm_alps() {
echo "---------- Zip OSM alps start"

rm -f "alps_osm_${mapdate}.zip"
ln -s alps_osm.img gmapsupp.img
zip -q "alps_osm_${mapdate}.zip" OSM_Alps.exe gmapsupp.img OSM_Alps.img OSM_Alps.tdb
rm -f gmapsupp.img

echo "---------- Zip OSM alps end"

}
function 37_zip_srtm_alps() {
echo "---------- Zip SRTM alps start"

rm -f "alps_srtm10_${mapdate}.zip" "alps_srtm20_${mapdate}.zip" "alps_srtm100_${mapdate}.zip"

# SRTM10 Zip file:
zip -q "alps_srtm10_${mapdate}.zip" alps_srtm10.img

# SRTM20 Zip file:
zip -q "alps_srtm20_${mapdate}.zip" alps_srtm20.img

# SRTM100 Zip file:
zip -q "alps_srtm100_${mapdate}.zip" alps_srtm100.img

echo "---------- Zip SRTM alps end"
}
function 38_md5sum_alps() {
echo "---------- md5sums alps start"

md5sum osm_srtm_alps_${mapdate}.zip alps_osm_${mapdate}.zip alps_srtm10_${mapdate}.zip alps_srtm20_${mapdate}.zip alps_srtm100_${mapdate}.zip alps_bldg_${mapdate}.zip > md5sums_alps.txt 

echo "---------- md5sums alps end"
}
function 42_delete_files() {
echo "---------- Delete start"

rm -f template_reb_alps.args alps_osm_srtm.img template_reb_alps_osm.args alps_osm.img template_reb_alps_srtm10.args alps_srtm10.img template_reb_alps_srtm20.args alps_srtm20.img template_reb_alps_srtm100.args alps_srtm100.img template_reb_alps_bldg.args Bldg_Alps.img Bldg_Alps.tdb alps_bldg.img template_ms_alps.args OSM_SRTM_Alps.img OSM_SRTM_Alps.tdb OSM_SRTM_Alps_mdr.img OSM_SRTM_Alps.mdx OSM_SRTM_Alps.nsi OSM_SRTM_Alps_license.txt gmt.exe OSM_SRTM_Alps.exe template_ms_alps_osm.args OSM_Alps.img OSM_Alps.tdb OSM_Alps_mdr.img OSM_Alps.mdx OSM_Alps.nsi OSM_Alps_license.txt OSM_Alps.exe template_ms_germany_osm.args OSM_Germany.img OSM_Germany.tdb OSM_Germany_mdr.img OSM_Germany.mdx OSM_Germany.nsi OSM_Germany.exe template_ms_germany.args OSM_SRTM_Germany.img OSM_SRTM_Germany.tdb OSM_SRTM_Germany_mdr.img OSM_SRTM_Germany.mdx OSM_SRTM_Germany.nsi OSM_SRTM_Germany_license.txt OSM_SRTM_Germany.exe germany_osm_srtm_ov.img template_reb_germany.args OV_Germany.img OV_Germany.tdb germany_osm_srtm.img OV_Germany_mdr.img OV_Germany.mdx template_reb_germany_osm.args germany_osm.img template_reb_germany_srtm10.args germany_srtm10.img template_reb_germany_srtm20.args germany_srtm20.img template_reb_germany_srtm100.args germany_srtm100.img template_reb_germany_building.args osmmap.img osmmap.tdb germany_bldg.img template_reb_germany_ov.args 10000000.img OSM_Germany_Alps_[1-6].img OSM_Germany_Alps_[1-6].tdb OSM_Germany_Alps_[1-6]_mdr.img OSM_Germany_Alps_[1-6].mdx


echo "---------- Delete end"
}

01_links
02_split
03_mkgmap_nobuilding
04_mkgmap_building
05_copy_tiles
06_reb_all_in_one
07_check_all_in_one
08_reb_osm
09_reb_srtm10
10_reb_srtm20
11_reb_srtm100
12_reb_bldg
13_ms_all_in_one
14_nsis_all_in_one
15_zip_all_in_one
16_ms_osm
17_nsis_osm
18_zip_osm
19_zip_srtm
20_md5sum
24_reb_all_in_one_alps
25_check_all_in_one_alps
26_reb_osm_alps
27_reb_srtm10_alps
28_reb_srtm20_alps
29_reb_srtm100_alps
30_reb_bldg_alps
31_ms_all_in_one_alps
32_nsis_all_in_one_alps
33_zip_all_in_one_alps
34_ms_osm_alps
35_nsis_osm_alps
36_zip_osm_alps
37_zip_srtm_alps
38_md5sum_alps
42_delete_files